Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3819)

Unified Diff: bfd/cpu-v850_rh850.c

Issue 124383005: GDB 7.6.50 (Closed) Base URL: http://git.chromium.org/native_client/nacl-gdb.git@upstream
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bfd/cpu-v850.c ('k') | bfd/cpu-xc16x.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: bfd/cpu-v850_rh850.c
diff --git a/bfd/cpu-v850.c b/bfd/cpu-v850_rh850.c
similarity index 58%
copy from bfd/cpu-v850.c
copy to bfd/cpu-v850_rh850.c
index d124220146cca9c7fece7ec63679ef8d52a753ab..9402f23a6d2d385c498e21f7d5d7a75e81981a86 100644
--- a/bfd/cpu-v850.c
+++ b/bfd/cpu-v850_rh850.c
@@ -1,6 +1,5 @@
-/* BFD support for the NEC V850 processor
- Copyright 1996, 1997, 1998, 2000, 2001, 2002, 2003, 2005, 2007,
- 2010 Free Software Foundation, Inc.
+/* BFD support for the NEC V850 processor with the RH850 ABI.
+ Copyright 2012-2013 Free Software Foundation, Inc.
This file is part of BFD, the Binary File Descriptor library.
@@ -24,22 +23,19 @@
#include "libbfd.h"
#include "safe-ctype.h"
-#define N(number, print, default, next) \
-{ 32, 32, 8, bfd_arch_v850, number, "v850", print, 2, default, \
+#define R(number, print, default, next) \
+{ 32, 32, 8, bfd_arch_v850_rh850, number, "v850", print, 2, default, \
bfd_default_compatible, bfd_default_scan, bfd_arch_default_fill, next }
-#define NEXT NULL
-
static const bfd_arch_info_type arch_info_struct[] =
{
- N (bfd_mach_v850e2v3, "v850e2v3", FALSE, & arch_info_struct[1]),
- N (bfd_mach_v850e2, "v850e2", FALSE, & arch_info_struct[2]),
- N (bfd_mach_v850e1, "v850e1", FALSE, & arch_info_struct[3]),
- N (bfd_mach_v850e, "v850e", FALSE, NULL)
+ R (bfd_mach_v850e3v5, "v850e3v5", FALSE, & arch_info_struct[1]),
+ R (bfd_mach_v850e3v5, "v850e2v4", FALSE, & arch_info_struct[2]),
+ R (bfd_mach_v850e2v3, "v850e2v3", FALSE, & arch_info_struct[3]),
+ R (bfd_mach_v850e2, "v850e2", FALSE, & arch_info_struct[4]),
+ R (bfd_mach_v850e1, "v850e1", FALSE, & arch_info_struct[5]),
+ R (bfd_mach_v850e, "v850e", FALSE, NULL)
};
-#undef NEXT
-#define NEXT & arch_info_struct[0]
-
-const bfd_arch_info_type bfd_v850_arch =
- N (bfd_mach_v850, "v850", TRUE, NEXT);
+const bfd_arch_info_type bfd_v850_rh850_arch =
+ R (bfd_mach_v850, "v850-rh850", TRUE, & arch_info_struct[0]);
« no previous file with comments | « bfd/cpu-v850.c ('k') | bfd/cpu-xc16x.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698